/*! \file getDevelopDb.c

 \brief Get development repository database

getDevelopDb downloads and unzips the database for the
development repository.
*/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

//! Base of wget commands used to retrieve the database
#define BASE "wget -q http://mirror.its.uidaho.edu/pub/fedora/linux/development/i386/os/"
//! Buffer for reading repomd.xml
char szBuffer[1024];
//! Command to Execute
char szCommand[256];

//! Get development database
/*! getDevelopDb is more of a script than an actual program.  The
    application first attempts to create a 'rawhide' subdirectory
    in case one doesn't exist.  It then downloads the repomd.xml file
    which contains the full name of the database.

    The XML file is searched for the location entry of the 
    primary.sqlite file.  When found, it picks the filename out of the
    XML and issues a wget for that file.  The file is then renamed
    to primary.sqlite.bz2, unzipped, and moved to the rawhide
    directory.

    Finally, the repomd.xml file is deleted.
*/
int main()
{

  FILE *f;
  char *p,*q;

  system("mkdir rawhide 2>/dev/null");

  strcpy(szCommand,BASE);
  strcat(szCommand,"repodata/repomd.xml");
  printf("Getting repomd.\n");
  system( szCommand );

  f = fopen("repomd.xml","r");
  if ( f == NULL )
    {
      perror("Opening repomd.xml");
      exit(1);
    }

  while ( !feof(f) )
    {
      fgets(szBuffer,sizeof(szBuffer),f);
      if ( !feof(f) )
	{
	  p = strstr(szBuffer,"<location href");
	  if ( p )
	    {
	      q = strstr(p,"primary.sqlite");
	      if ( q )
		{
		  //printf("[%s]\n",p);
		  //printf("(%s)\n",q);
		  p += 16;
		  //printf("{%s}\n",p);
		  q = strchr(p,'\"');
		  if ( q )
		    {
		      *q='\0';
		      //printf("<%s>\n",p);
		      strcpy(szCommand,BASE);
		      strcat(szCommand,p);
		      printf("Getting .bz2 (this may take a while)\n");
		      system( szCommand );
		      p += 9;
		      strcpy(szCommand,"mv ");
		      strcat(szCommand,p);
		      strcat(szCommand," primary.sqlite.bz2");
		      printf("Renaming .bz2\n");
		      system( szCommand );
		      printf("Unzipping .bz2 (this isn't exactly quick either)\n");
		      system("bunzip2 primary.sqlite.bz2");
		      printf("Moving .bz2\n");
		      system("rm -f rawhide/primary.bz2 2>/dev/null");
		      system("mv primary.sqlite rawhide");
		    } 
		  else
		    {
		      fprintf(stderr,"Badly formated location string\n");
		      exit(1);
		    }
		}
	    }
	}
    }
  fclose(f);

  system("rm -f repomd.xml");
  exit(0);
}

