/*! \file copyFiles.c

    \brief Copy Publican files to staging area

    The rpm must include a source tar file.  This tar is staged
    in the working directory.  The tar file includes the files
    necessary for the document, as well as the desktop file and
    the top level index.html.  copyFiles() copies the Publican
    files to that directory tree.

\dot
digraph PubDirs
{
  size="4.0,4.0";
  rankdir="LR";
  fontname="Helvetica-Bold";
  label="Publican document structure";
  node [ style="filled" fillcolor="wheat" fontname="Helvetica" ];
  "index.html (en-US)" [ shape="record" fillcolor="lightyellow"
                         label="(document files)" ];
  "index.html (de-DE)" [ shape="record" fillcolor="lightyellow" 
                         label="(document files)" ];
  "Article_Info.xml (en-US)" [ shape="record" fillcolor="lightyellow" 
                               label="Article_Info.xml" ];
  "Article_Info.xml (de-DE)" [ shape="record" fillcolor="lightyellow" 
                               label="Article_Info.xml" ];
  "<basename>" -> tmp;
  tmp -> "de-DE";
  tmp -> "en-US";
  "html (en-US)" [ label="html"];
  "html-single (en-US)" [ label="html-single"];
  "xml (en-US)" [ label="xml"];
  "en-US" -> "html (en-US)";
  "en-US" -> "html-single (en-US)";
  "en-US" -> "xml (en-US)";
  "html (de-DE)" [ label="html"];
  "html-single (de-DE)" [ label="html-single"];
  "xml (de-DE)" [ label="xml"];
  "de-DE" -> "html (de-DE)";
  "de-DE" -> "html-single (de-DE)";
  "de-DE" -> "xml (de-DE)";
  "html (en-US)" -> "index.html (en-US)";
  "html (de-DE)" -> "index.html (de-DE)";
  "xml (en-US)" -> "Article_Info.xml (en-US)";
  "xml (de-DE)" -> "Article_Info.xml (de-DE)";
}
\enddot
\dot
digraph BuildDirs
{
  size="4.0,4.0";
  rankdir="LR";
  fontname="Helvetica-Bold";
  label="Work directory structure";
  node [ style="filled" fillcolor="wheat" fontname="Helvetica" ];
  "index.html (en-US)" [ shape="record" fillcolor="lightyellow"
			 label="(document files)" ];
  "index.html (de-DE)" [ shape="record" fillcolor="lightyellow" 
			 label="(document files)" ];
  "index.html" [ shape="record" fillcolor="lightyellow" ];
  "basename.desktop" [ shape="record" fillcolor="lightyellow" ];
  "<basename>-<version>" -> desktop;
  "<basename>-<version>" -> document;
  "<basename>-<version>" -> "index.html";
  desktop  -> "basename.desktop";
  document -> "en-US";
  document -> "de-DE";
  "en-US" -> "index.html (en-US)";
  "de-DE" -> "index.html (de-DE)";
}
\enddot
    In addition, doc-publican-rpm temporarily provides the
    icon files.  These are available in /usr/share/doc-publican-rpm
    and need to be included in the target rpm, so here they are
    added to the working directory so they will end up in the tar.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

extern int nEntry;

extern struct
{
  char szLang[16];
  char szTitle[128];
  char szSubtitle[512];
} rcConvInfo[50];

extern char szWorkdir[256];
extern char szPubDir[512];

/*! copyFiles() - copy Publican document to work area

    The Publican html files and associated images and style files
    are copied into the appropriate language directory in the area
    where the tar is being staged.  Languages are copied individually
    since the tar layout is slightly different than the Publican
    layout.

    In addition, the icons are copied into the work area.
*/
void copyFiles( void )
{
  char szFromDir[512];
  char szToDir[512];
  char szCommand[512];
  int i;

  // Build directory structure from which tar will be made
  strcpy(szCommand,"rm -Rf ");
  strcat(szCommand,szWorkdir);
  system(szCommand);
  strcpy(szCommand,"mkdir ");
  strcat(szCommand,szWorkdir);
  printf("Copying files.\n");
  system(szCommand);
  strcat(szCommand,"/document");
  system(szCommand);
  szCommand[strlen(szCommand)-9]='\0';
  strcat(szCommand,"/desktop");
  system(szCommand);

  printf("%d languages to copy.\n",nEntry);
  for ( i=0; i<nEntry; i++ )
    {
      strcpy(szFromDir,szPubDir);
      strcat(szFromDir,"/tmp/");
      strcat(szFromDir,rcConvInfo[i].szLang);
      strcat(szFromDir,"/html/*");

      strcpy(szToDir,szWorkdir);
      strcat(szToDir,"/document/");
      strcat(szToDir,rcConvInfo[i].szLang);
      strcpy(szCommand,"mkdir ");
      strcat(szCommand,szToDir);

      //printf("%s\n",szCommand);
      system(szCommand);

      //printf("--------------------------\n");
      //system("ls -R");

      strcpy(szCommand,"cp -R ");
      strcat(szCommand,szFromDir);
      strcat(szCommand," ");
      strcat(szCommand,szToDir);

      //printf("%s\n",szCommand);
      system(szCommand);
    }

  strcpy(szCommand,"cp -r /usr/share/doc-publican-rpm/icons ");
  strcat(szCommand,szWorkdir);
  system(szCommand);

}
