/*! \file getLanguages.c

\brief Determine what languages are available

    getLangauages() looks through the Publican tmp directory tree and
    identifies those languages for which an <tt>index.html</tt> file
    is available.  */

/* Include files */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dirent.h>

extern struct
{
  char szLang[16];
  char szTitle[128];
  char szSubtitle[512];
} rcConvInfo[50];
extern int nEntry;

//! Directory structure for opendir()
DIR *dir;
//! Directory entry
struct dirent *de;


/*! getLanguages() - Identify the languages to be processed

    getLangauages() looks through the Publican tmp directory tree and
    identifies those languages for which an <tt>index.html</tt> file
    is available.

    getLanguages looks through each of the tmp directories for
    each language.  It checks to see whether a 
    <tt>tmp/lang/html/index.html</tt> file exists.  If it does,
    it assumes that language needs to be packaged.

    Languages found are stored in the rcConvInfo structure. U.S.
    English is always entry 0 in that structure.
*/
void getLanguages( char *szDir )
{
  char szTempDir[512];
  char szIndexName[512];
  FILE *f;
  //int i;

  strcpy(szTempDir,szDir);
  strcat(szTempDir,"/tmp");
  dir = opendir( szTempDir );

  if ( dir == NULL )
    {
      perror("Checking directory");
      exit(1);
    }
  //printf("%s opened\n",szTempDir);

  nEntry = 1;
  do
    {
      de = readdir( dir );
      if ( de != NULL )
	{
	  if ( strcmp(de->d_name,".") && strcmp(de->d_name,"..") )
	    {
	      if ( !strcmp(de->d_name,"en-US") )
		{
		  strcpy(rcConvInfo[0].szLang,de->d_name);
		}
	      else
		{
		  strcpy(szIndexName,szTempDir);
		  strcat(szIndexName,"/");
		  strcat(szIndexName,de->d_name);
		  strcat(szIndexName,"/html/index.html");
		  //printf("Opening %s.\n",szIndexName);
		  f = fopen(szIndexName,"r");
		  //printf("%s opened.\n",szIndexName);
		  if ( f )
		    {
		      //printf("\t-->(%02d) %s<--\n",nEntry,de->d_name);
		      strcpy(rcConvInfo[nEntry].szLang,de->d_name);
		      nEntry++;
		      fclose(f);
		    }
		}
	    }
	}
    } while ( de != NULL );

  //for ( i=0; i<nEntry; i++ )
  //  printf("\t(%02d):\t%s\n",i,rcConvInfo[i].szLang);
}
