/*! \file readConfigFile.c

\brief Reads the doc-publican-rpm.config file

  Get the following information from the config file:
    - Author name
    - Author email
    - Directory for publican files
    - Version number of the rpm
    - Release number of the rpm

*/

/* Include files */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

extern char szVersion[20];
extern char szRelease[16];
extern char szPubDir[512];
extern char szAuthor[128];
extern char szEmail[128];

/*! readConfigFile() - gets basic information from config.

    Arguments:
    \arg configfile - Pointer to name of config file
 */
void readConfigFile( char *configfile )
{
  FILE *cf;

  cf = fopen(configfile,"r");
  if ( cf == NULL )
    {
      perror("opening config file");
      exit(1);
    }

  fgets(szAuthor,sizeof(szAuthor),cf);
  if ( szAuthor[strlen(szAuthor)-1]<' ' )
    szAuthor[strlen(szAuthor)-1] = '\0';
  printf("  Author: [%s].\n",szAuthor);

  fgets(szEmail,sizeof(szEmail),cf);
  if ( szEmail[strlen(szEmail)-1]<' ' )
    szEmail[strlen(szEmail)-1] = '\0';
  printf("   Email: [%s].\n",szEmail);

  fgets(szPubDir,sizeof(szPubDir),cf);
  if ( szPubDir[strlen(szPubDir)-1]<' ' )
    szPubDir[strlen(szPubDir)-1] = '\0';
  printf(" Pub Dir: [%s].\n",szPubDir);

  fgets(szVersion,sizeof(szVersion),cf);
  if ( szVersion[strlen(szVersion)-1]<' ' )
    szVersion[strlen(szVersion)-1] = '\0';
  printf(" Version: [%s].\n",szVersion);

  fgets(szRelease,sizeof(szRelease),cf);
  if ( szRelease[strlen(szRelease)-1]<' ' )
    szRelease[strlen(szRelease)-1] = '\0';
  printf(" Release: [%s].\n",szRelease);

  fclose( cf );
}
