/*! \file makeTechNotes.c

  \brief Make XML tables for all rpm groups in a repo

makeTechNotes reads a file listing the rpm_groups in a for which
tables are desired.  For each rpm group, it queries the "new"
primary.sqlite for all the packages in that group.  These are written
to a temporary file which is then passed to makeOneTable to generate
the appropriate XML table.

A listing of all the rpm groups is generated for a new release by:
\code
sqlite3 --noheader new/primary.sqlite \
    "SELECT DISTINCT rpm_group FROM packages ORDER BY rpm_group"
\endcode
This is output written to a file which is read by makeTechNotes.

\dot
digraph
{
  size="3.0,4.0";
  label="Program/File connections";
  fontname="Helvetica-Bold";
  "new\nprimary.sqlite" [ style=filled fillcolor=cornsilk
    fontname="Helvetica" ];
  "old\nprimary.sqlite" [ style=filled fillcolor=cornsilk
    fontname="Helvetica" ];
  tempfiles [ style=filled fillcolor=palegoldenrod
    fontname="Helvetica" ];
  makeTechNotes [ shape=record style=filled fillcolor=palegreen
    fontname="Helvetica" ];
  makeOneTable [ shape=record style=filled fillcolor=palegreen
    fontname="Helvetica" ];
  "Multiple\nXML" [ style=filled fillcolor=salmon];
  "new\nprimary.sqlite" -> makeTechNotes;
  "new\nprimary.sqlite" -> makeOneTable;
  "old\nprimary.sqlite" -> makeOneTable;
  makeTechNotes -> tempfiles;
  makeTechNotes -> makeOneTable [ style="dotted" ];
  tempfiles -> makeOneTable;
  makeOneTable -> "Multiple\nXMLs";
}
\enddot
*/
#include <stdio.h>
#include <string.h>

//! Generate XML tables showing the differences between old and new versions
/*! makeTechNotes main() reads a file of rpm groups.  For each group
    it locates all the packages in that group and calls makeOneTable to
    create the XML for that table.
 */
int main( int argc, char *argv[] )
{
  FILE *f,*g;
  char szBeatName[128];
  char szFileName[128];
  char szCommand[256];
  char szSQL[256];
  char *p,*q;


  f = fopen(argv[1],"r");
  if ( f == NULL )
    {
      perror("Opening");
      return 1;
    }
  g = fopen("Changes.xml","w");
  if ( g== NULL )
    {
      perror("Creating");
      return 1;
    }

  while ( !feof(f) )
    {
      fgets(szBeatName,sizeof(szBeatName),f);
      if ( !feof(f) )
	if ( szBeatName[0] != '%' )
	  {
	    szBeatName[strlen(szBeatName)-1]='\0';
	    //printf("[%s]\n",szBeatName);
	    p = szBeatName;
	    q = szFileName;
	    while ( *p )
	      {
		*q = *p;
		if ( *p == ' ' ) *q = '_';
		if ( *p == '/' ) *q = '-';
		if ( *p == '(' ) *q = '_';
		if ( *p == ')' ) *q = '_';
		p++; q++;
	      }
	    *q = '\0';
	    strcat(szFileName,".beat");
	    printf("\t(%s)\n",szFileName);
	    strcpy(szSQL,"SELECT name FROM packages WHERE rpm_group = '");
	    strcat(szSQL,szBeatName);
	    strcat(szSQL,"' ORDER BY name;");
	    strcpy(szCommand,"sqlite3 new/primary.sqlite \"");
	    strcat(szCommand,szSQL);
	    strcat(szCommand,"\" >");
	    strcat(szCommand,szFileName);
	    system(szCommand);

	    strcpy(szCommand,"./makeOneTable ");
	    strcat(szCommand,szFileName);
	    strcat(szCommand," >");
	    szFileName[strlen(szFileName)-4] = '\0';
	    strcat(szFileName,"xml");
	    strcat(szCommand,szFileName);
	    //printf("{%s}\n",szCommand);
	    system(szCommand);
	    fprintf(g,"  <xi:include href=\"%s\"\n    xmlns:xi=\"http://www.w3.org/2001/XInclude\">\n  </xi:include>\n",szFileName);
	  }
    }

  return 0;
}
